
% ========================================================================
% 
%   MatLab or Octave program to calculate a deHoffman-Teller velocity,
%   i.e., a velocity where the residual electric field is minimized.
%   See e.g., ISSI book on multi-SC analysis, chapter 9
%
%   SEH, GP, 01 Jun 2007
%
% ========================================================================



%%  --- first we load the data matrix  -----

data = load("C3.txt");
V = data(:, 1:3);
B = data(:, 4:6);
N = data(:, 6);
nsamples=size(B)(1);


%% --- declare some temporary variables ---

K  = zeros(3,3);
K0 = zeros(3,3);
KV = zeros(3);



%% --- calculate averages - see eq 9.9 in blue book ---

for k=1:nsamples, 
   BB=norm(B(k,:));
   for i=1:3,
      for j=1:3,
        K(i,j) = BB*BB*(i==j) - B(k,i)*B(k,j);
        K0(i,j) += K(i,j);
        KV(i) += K(i,j) * V(k,j);
      end
   end
end

KV /= nsamples;
K0 /= nsamples;




%% --- Solve for Vht - see eq 9.10 in blue book ---

Vht  = (inverse(K0)' * KV);
printf("Vht = [%8.5f %8.5f  %8.5f]\n", Vht(:,1));



