;+
; NAME:
;       hoftel
;
; PURPOSE:
;
;       This little program performs a de-Hoffmann-Teller analysis and
;       returns the deHoffmann-Teller velocity
;       See e.g., ISSI book on multi-SC analysis, chapter 9
;
; AUTHOR:
;
;       SEH, GP, May 2007
;
; CATEGORY:
;       Utilities
;
;
; REQUIRED INPUTS:
;
;       none, but the example file 'C1.txt' or 'C3.txt'must be present in
;       the working directory
;
; MODIFICATION HISTORY:
;
;       Written by:  SEH, 10 Oct, 2005  (initial version)
;		     SEH, 31 may 2007   (modified for Sinaia 07)	
;
;

PRO hoftel



; --- first we read the data into the variable D 
; --- note that indices start on 0 in IDL


ASCII  = READ_ASCII("C3.txt", COUNT=nsamp);
V = ASCII.field1(0:2, 0:nsamp-1); 
B = ASCII.field1(3:5, 0:nsamp-1); 
N = ASCII.field1(6,   0:nsamp-1); 



; --- declare some temporary variables ---

K  = fltarr(3,3);
K0 = fltarr(3,3);
KV = fltarr(3);


;  --- calculate averages - see eq 9.9 in blue book 
;  --- note that rows  and colums are opposite of matlab/octave

for c=0,nsamp-1 do Begin
   BB=norm(B(*,c));
   for i=0,2 do Begin
      for j=0,2 do Begin
        K(j,i) = BB*BB*(i EQ J) - B(i,c)*B(j,c);
        K0(j,i) = K0(j,i) + K(j,i);
        KV(i) = KV(i) + K(j,i) * V(j,c);
      End
   End
End


   
KV = KV/nsamp;
K0 = K0/nsamp;



; --- Solve for Vht - see eq 9.10 in blue book 

Vht = INVERT(K0) # KV
print, "Vht = ",Vht


END; of Hoftel routine



