;+
; NAME:
;       mvar
;
; PURPOSE:
;
;       This little program performs some of the calculations in 
;       Chapter 1 of the Multipoint Methods
;
; AUTHOR:
;
;       SEH, May 2007
;
; CATEGORY:
;       Utilities
;
;
; REQUIRED INPUTS:
;
;       none, but the example file 'B_field_SC2.txt' must be present in
;       the working directory
;
; MODIFICATION HISTORY:
;
;       Written by:  SEH, 10 Oct, 2005  (initial version)
;		     SEH, 31 may 2007   (modified for Sinaia 07)	
;
;

PRO mvar


;  first we read the data into the variable D 
;  note that indices start on 0 in IDL


ASCII  = READ_ASCII("B_field_SC2.txt", COUNT=N);
D = ASCII.field1(0:2, 0:16); 

print,'D='
print,D 


;  averaging each column to get mean

AveB = fltarr(3,1)
for i=0,2 do AveB(i) = MEAN(D(i,*))

print,'AveB ='
print,AveB


;  calculate the mean adjusted matrix B

B = fltarr(3,17)
for i=0,2 do B(i,*) = D(i,*) - AveB(i)

print,'B = '
print,B

;  calculate the covariance matrix, 
;  note the ## operator for matrix multiplication in IDL 

Q = TRANSPOSE(B) ## B / N

print,'Q = '
print,Q


;  eigenvalues and eigenvectors 

lambda = EIGENQL(Q,EIGENVECTORS=A)

print,'lambda = '
print,lambda
print,'A = '
print,A



;  rotate the X matrix to get Y (principal components)

Y = B ## TRANSPOSE(A)

print,'Y = '
print,Y



;  Singular Value Decomposition (SVD)
;  see also the IDL SVDC routine 

SVDC, B, W, U, V

print,'W ='
print, W
print,'V ='
print, V
print,'U='
print, Q



;  To verify, represent W as a 3x3 matrix (jfr Eq. 3.21) and use Eq. 3.20 :


Wm = fltarr(3,3)
for i=0,2 do Wm[i,i] = W[i]

B = U  ##  Wm  ##   TRANSPOSE(V)

print,'B ='
print,B


End ; of mvar routine
